﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
       
        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = new ViewModel();
        }

        private void GroupByRowCellsPanel_Loaded(object sender, RoutedEventArgs e)
        {
            if ((sender as GroupByRowCellsPanel).Row != null)
                ((sender as GroupByRowCellsPanel).Row as Row).IsExpanded = true;
        }       
       
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            /// <summary>
            /// Open a user control by passing the selected grid row value.
            /// We change some values throug control that open, and these values are saved in database.
            /// Than we fetch all records from data base like first stage of page (first time open) and display all records in grid.
            /// Now i want to select (highlight) the row that i modify through user control.
            /// 
            /// 
            /// This is my requirement. How can we achieve that goal ?
            /// </summary>            

            ///We fetch changed record from database and show in grid.
            ///At this stage my page is refreshed
            this.DataContext = Data.GetData(10, 0, 4);

            /// After this situation i want to select (higlight) the row that i modify 
            /// not again opend all groups again may be user collapsed some groups.
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private int open;
        private int close;
        private int high;
        private int low;
        private string label;
        private DateTime date;


        public DateTime Date
        {
            get { return date; }
            set
            {
                date = value;
                PropChanged("Date");
            }
        }


        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Open
        {
            get { return open; }
            set
            {
                open = value;
                PropChanged("Open");
            }
        }

        public int Close
        {
            get { return close; }
            set
            {
                close = value;
                PropChanged("Close");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Low
        {
            get { return low; }
            set
            {
                low = value;
                PropChanged("Low");
            }
        }

        public double Avarage
        {
            get
            {
                return (Open + Close + High + Low) / 4;
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Date = DateTime.Now.AddDays(i),
                    Label = "Item " + i,
                    Open = r.Next(rangeStart, rangeEnd),
                    Close = r.Next(rangeStart, rangeEnd),
                    High = r.Next(rangeStart, rangeEnd),
                    Low = r.Next(rangeStart, rangeEnd),
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }

    public class ViewModel : INotifyPropertyChanged
    {
        public ViewModel()
        {
            MyData = Data.GetData(10, 0, 10);
        }

        public ObservableCollection<Data> MyData { get; set; }

        private Data myActiveItem;

        public Data MyActiveItem
        {
            get 
            { 
                return myActiveItem;
            }
            set 
            { 
                myActiveItem = value; 
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }

    }
}
